@@ -4,10 +4,10 @@
 
 __author__ = 'onlytiancai'
 __author_email__ = 'onlytiancai@gmail.com'
-__version__ = '1.0'
+__version__ = '1.0.1'
 
 class Car(object):
     color = 'red'
-    def run():
+    def run(self):
         '跑起来吧'
         print "I'm runing." 
